Package: tubern
Title: R Client for the YouTube Analytics and Reporting API
Version: 0.5.0
Authors@R: person("Gaurav", "Sood", email = "gsood07@gmail.com", role = c("aut", "cre"))
Author: Gaurav Sood [aut, cre]
Maintainer: Gaurav Sood <gsood07@gmail.com>
Description: Provides access to YouTube Analytics API v2 for retrieving 
    YouTube Analytics data including views, engagement metrics, demographics, and 
    revenue data. Supports OAuth 2.0 authentication and channel group management. 
    See <https://developers.google.com/youtube/analytics/> for API documentation.
URL: https://github.com/gojiplus/tubern
BugReports: https://github.com/gojiplus/tubern/issues
Depends: R (>= 4.1.0)
License: MIT + file LICENSE
Encoding: UTF-8
Language: en-US
Imports: httr, jsonlite, checkmate, rlang (>= 1.1.0)
VignetteBuilder: knitr
Suggests: knitr (>= 1.11), testthat, httptest, rmarkdown, xml2, lintr,
        covr, ggplot2, tibble
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-12 05:41:31 UTC; soodoku
Repository: CRAN
Date/Publication: 2026-04-12 16:00:02 UTC
Built: R 4.5.2; ; 2026-04-15 05:07:22 UTC; unix
