# Generated by roxygen2: do not edit by hand

export(add_group_item)
export(add_groups)
export(check_api_quota)
export(delete_group)
export(delete_group_item)
export(diagnose_tubern)
export(get_audience_demographics)
export(get_available_dimensions)
export(get_available_metrics)
export(get_channel_overview)
export(get_common_date_ranges)
export(get_daily_performance)
export(get_geographic_performance)
export(get_report)
export(get_revenue_report)
export(get_top_videos)
export(list_group_items)
export(list_groups)
export(resolve_date_range)
export(update_group)
export(yt_export_csv)
export(yt_extract_summary)
export(yt_oauth)
export(yt_quick_plot)
export(yt_to_dataframe)
export(yt_to_tibble)
importFrom(checkmate,assert_character)
importFrom(checkmate,assert_flag)
importFrom(checkmate,assert_int)
importFrom(checkmate,assert_list)
importFrom(checkmate,assert_number)
importFrom(checkmate,assert_string)
importFrom(checkmate,check_string)
importFrom(graphics,barplot)
importFrom(graphics,points)
importFrom(httr,DELETE)
importFrom(httr,GET)
importFrom(httr,POST)
importFrom(httr,PUT)
importFrom(httr,authenticate)
importFrom(httr,config)
importFrom(httr,content)
importFrom(httr,oauth2.0_token)
importFrom(httr,oauth_app)
importFrom(httr,oauth_endpoints)
importFrom(httr,stop_for_status)
importFrom(httr,upload_file)
importFrom(jsonlite,toJSON)
importFrom(rlang,abort)
importFrom(rlang,caller_env)
importFrom(rlang,inform)
importFrom(rlang,warn)
importFrom(stats,median)
importFrom(utils,URLencode)
importFrom(utils,adist)
importFrom(utils,packageVersion)
importFrom(utils,write.csv)
