% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/delete_group.R
\name{delete_group}
\alias{delete_group}
\title{Delete Group}
\usage{
delete_group(id, ...)
}
\arguments{
\item{id}{String. Required.
``The id parameter specifies the YouTube group ID of the group that is being deleted.''}

\item{\dots}{Additional arguments passed to \code{\link[tubern]{tubern_DELETE}}.}
}
\value{
named list
}
\description{
Delete Group
}
\examples{

\dontrun{
delete_group(id="ABZZzGSIAAA")
}
}
\references{
\url{https://developers.google.com/youtube/analytics/reference/groups/delete}
}
