% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tubern.R
\name{tubern_GET}
\alias{tubern_GET}
\title{Base POST AND GET functions. Not exported.}
\usage{
tubern_GET(path, query = NULL, ...)
}
\arguments{
\item{path}{path to specific API request URL}

\item{query}{query list}

\item{\dots}{Additional arguments passed to \code{\link[httr]{GET}}.}
}
\value{
list
}
\description{
GET
}
