% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/add_groups.R
\name{add_groups}
\alias{add_groups}
\title{Add Groups}
\usage{
add_groups(resource_details, ...)
}
\arguments{
\item{resource_details}{Named nested list. Required. Must provide:
snippet with title (required), and optionally description and contentDetails with itemType}

\item{\dots}{Additional arguments passed to \code{\link[tubern]{tubern_POST}}.}
}
\value{
named list
}
\description{
Creates a new channel group.
}
\examples{

\dontrun{
add_groups(list(
  snippet = list(
    title = "My Channel Group",
    description = "A group for organizing channels"
  ),
  contentDetails = list(itemType = "youtube#channel")
))
}
}
\references{
\url{https://developers.google.com/youtube/analytics/reference/groups/insert}
}
