% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/error_handling.R
\name{diagnose_tubern}
\alias{diagnose_tubern}
\title{Diagnose common tubern issues}
\usage{
diagnose_tubern()
}
\value{
Diagnostic information about tubern setup
}
\description{
Diagnose common tubern issues
}
\examples{
\dontrun{
diagnose_tubern()
}
}
