% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/list_group_items.R
\name{list_group_items}
\alias{list_group_items}
\title{List Group Items}
\usage{
list_group_items(group_id, ...)
}
\arguments{
\item{group_id}{String. Required. ID of the group}

\item{\dots}{Additional arguments passed to \code{\link[tubern]{tubern_GET}}.}
}
\value{
named list
}
\description{
List Group Items
}
\examples{
\dontrun{
list_group_items(group_id = "vponEBg8hrR1yBUX0Hz66Uc5WMk/vyGp6PvFo4RvsFtPoIWeCReyIC8")
}
}
\references{
\url{https://developers.google.com/youtube/analytics/reference/groupItems/list}
}
