% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/list_groups.R
\name{list_groups}
\alias{list_groups}
\title{List Groups}
\usage{
list_groups(filter, page_token = NULL, ...)
}
\arguments{
\item{filter}{Named Vector. Required. Only one of the two: id or mine.
id: Comma-separated list of YouTube group ID(s) to retrieve.
mine: Set to TRUE to retrieve all groups owned by the authenticated user.}

\item{page_token}{String. Optional. Identifies a specific page in the result set that should be returned.}

\item{\dots}{Additional arguments passed to \code{\link[tubern]{tubern_GET}}.}
}
\value{
named list
}
\description{
List Groups
}
\examples{
\dontrun{
list_groups(filter = c(mine = TRUE))
}
}
\references{
\url{https://developers.google.com/youtube/analytics/reference/groups/list}
}
