% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/report_helpers.R
\name{get_daily_performance}
\alias{get_daily_performance}
\title{Get daily performance time series}
\usage{
get_daily_performance(
  date_range,
  end_date = NULL,
  ids = "channel==MINE",
  metrics = c("views", "estimatedMinutesWatched"),
  ...
)
}
\arguments{
\item{date_range}{Date range string or start date}

\item{end_date}{End date (only needed if date_range is a specific start date)}

\item{ids}{Channel identifier (default: "channel==MINE")}

\item{metrics}{Vector of metrics to include (default: views, estimatedMinutesWatched)}

\item{...}{Additional arguments passed to get_report()}
}
\value{
API response with daily time series data
}
\description{
Retrieves day-by-day performance metrics for trend analysis.
}
\examples{
\dontrun{
# Daily views for last 30 days
get_daily_performance("last_30_days")

# Daily performance with engagement metrics
get_daily_performance("this_month", metrics = c("views", "likes", "comments", "shares"))
}
}
