% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tubern.R
\name{tubern_POST}
\alias{tubern_POST}
\title{POST}
\usage{
tubern_POST(path, query = NULL, body = "", ...)
}
\arguments{
\item{path}{path to specific API request URL}

\item{query}{query list}

\item{body}{passing image through body}

\item{\dots}{Additional arguments passed to \code{\link[httr]{POST}}.}
}
\value{
list
}
\description{
POST
}
