% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tubern.R
\docType{package}
\name{tubern}
\alias{tubern-package}
\alias{tubern}
\title{\pkg{tubern} provides access to the YouTube Analytics and Reporting API}
\description{
Provides access to YouTube Analytics API v2 for retrieving YouTube Analytics data including views, engagement metrics, demographics, and revenue data. Supports OAuth 2.0 authentication and channel group management. See \url{https://developers.google.com/youtube/analytics/} for API documentation.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/gojiplus/tubern}
  \item Report bugs at \url{https://github.com/gojiplus/tubern/issues}
}

}
\author{
\strong{Maintainer}: Gaurav Sood \email{gsood07@gmail.com}

}
