% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_transformation.R
\name{yt_to_tibble}
\alias{yt_to_tibble}
\title{Convert API response to tibble (if tibble is available)}
\usage{
yt_to_tibble(api_response, ...)
}
\arguments{
\item{api_response}{API response from YouTube Analytics}

\item{...}{Additional arguments passed to yt_to_dataframe()}
}
\value{
tibble or data.frame if tibble not available
}
\description{
Convert API response to tibble (if tibble is available)
}
\examples{
\dontrun{
report <- get_top_videos("last_7_days")
tbl <- yt_to_tibble(report)
}
}
