% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/add_group_item.R
\name{add_group_item}
\alias{add_group_item}
\title{Add Group Item}
\usage{
add_group_item(resource_details, ...)
}
\arguments{
\item{resource_details}{Named nested list. Required. Must provide:
groupId, resource.id}

\item{\dots}{Additional arguments passed to \code{\link[tubern]{tubern_POST}}.}
}
\value{
named list
}
\description{
Add Group Item
}
\examples{

\dontrun{
add_group_item(list(groupId = "", resource.id ="hello"))
}
}
\references{
\url{https://developers.google.com/youtube/analytics/reference/groupItems/insert}
}
