% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/date_helpers.R
\name{get_common_date_ranges}
\alias{get_common_date_ranges}
\title{Get common date ranges}
\usage{
get_common_date_ranges()
}
\value{
Named list of common date ranges
}
\description{
Get common date ranges
}
\examples{
get_common_date_ranges()
}
