% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/report_helpers.R
\name{get_revenue_report}
\alias{get_revenue_report}
\title{Get revenue report (requires monetary scope)}
\usage{
get_revenue_report(
  date_range,
  end_date = NULL,
  ids = "channel==MINE",
  currency = "USD",
  include_cpm = TRUE,
  ...
)
}
\arguments{
\item{date_range}{Date range string or start date}

\item{end_date}{End date (only needed if date_range is a specific start date)}

\item{ids}{Channel identifier (default: "channel==MINE")}

\item{currency}{Currency code (default: "USD")}

\item{include_cpm}{Logical. Include CPM metrics (default: TRUE)}

\item{...}{Additional arguments passed to get_report()}
}
\value{
API response with revenue data
}
\description{
Retrieves revenue and monetization metrics.
}
\examples{
\dontrun{
# Revenue report for last month
get_revenue_report("last_month")

# Revenue in different currency
get_revenue_report("this_quarter", currency = "EUR")
}
}
