% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/report_helpers.R
\name{get_channel_overview}
\alias{get_channel_overview}
\title{Get channel overview report}
\usage{
get_channel_overview(
  date_range,
  end_date = NULL,
  ids = "channel==MINE",
  include_engagement = TRUE,
  include_subscribers = TRUE,
  ...
)
}
\arguments{
\item{date_range}{Date range string like "last_30_days" or start date for custom range}

\item{end_date}{End date (only needed if date_range is a specific start date)}

\item{ids}{Channel identifier (default: "channel==MINE")}

\item{include_engagement}{Logical. Include likes, dislikes, comments, shares (default: TRUE)}

\item{include_subscribers}{Logical. Include subscriber metrics (default: TRUE)}

\item{...}{Additional arguments passed to get_report()}
}
\value{
API response with channel overview data
}
\description{
Retrieves key channel performance metrics for a specified time period.
}
\examples{
\dontrun{
# Channel performance for last 30 days
get_channel_overview("last_30_days")

# Channel performance for specific date range
get_channel_overview("2024-01-01", end_date = "2024-01-31")

# Basic metrics only
get_channel_overview("this_month", include_engagement = FALSE, include_subscribers = FALSE)
}
}
